pub struct GenericInstructionData {
pub instruction_data: Vec<u8>,
}Fields
instruction_data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for GenericInstructionData
impl BorshDeserialize for GenericInstructionData
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for GenericInstructionData
impl Clone for GenericInstructionData
Sourcefn clone(&self) -> GenericInstructionData
fn clone(&self) -> GenericInstructionData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for GenericInstructionData
impl RefUnwindSafe for GenericInstructionData
impl Send for GenericInstructionData
impl Sync for GenericInstructionData
impl Unpin for GenericInstructionData
impl UnwindSafe for GenericInstructionData